pub struct AlignedHash { /* private fields */ }Expand description
A hash aligned to a cache line boundary.
This prevents false sharing when multiple threads access adjacent hashes and ensures optimal cache behavior for frequently accessed hashes.
Implementations
Sourceimpl AlignedHash
impl AlignedHash
Sourcepub fn into_inner(self) -> Hash
pub fn into_inner(self) -> Hash
Consume and return the inner hash.