Module block

Module block 

Block types for Moloch.

Blocks batch audit events together and link to form the chain.

Structs

Block
A complete block with header and events.
BlockBuilder
Builder for creating blocks.
BlockHash
Unique identifier for a block (hash of header).
BlockHeader
Block header containing metadata and proofs.
SealerId
Identifies a sealer (block producer).

Functions

compute_events_root
Compute the merkle root of a list of events.
compute_events_root_parallel
Compute the merkle root using parallel hashing.