Module proof

Module proof 

Proof types for Moloch.

Proofs allow verifying that an event exists in the chain without having to download the entire chain.

Structs

BlockInclusionProof
Proof that an event is included in a specific block.
ConsistencyProof
Proof that one chain state is a prefix of another.
InclusionProof
Complete inclusion proof (block + MMR).
MmrProof
MMR (Merkle Mountain Range) proof for chain inclusion.
ProofNode
A node in a merkle proof path.

Enums

Position
Position of a sibling in a merkle proof.