pub struct ConsistencyProof {
pub old_size: u64,
pub new_size: u64,
pub old_root: Hash,
pub new_root: Hash,
pub proof: Vec<Hash>,
}Expand description
Proof that one chain state is a prefix of another.
This is used for auditing: an auditor can verify that the chain they observed previously is consistent with the current chain.
Fields
old_size: u64Old MMR size (number of leaves).
new_size: u64New MMR size.
old_root: HashOld MMR root.
new_root: HashNew MMR root.
proof: Vec<Hash>Proof nodes (old peaks that can be derived from new tree).
Implementations