pub struct Capability { /* private fields */ }Expand description
A specific permission granted to an agent.
Implementations
Sourceimpl Capability
impl Capability
Sourcepub fn builder() -> CapabilityBuilder
pub fn builder() -> CapabilityBuilder
Create a new capability builder.
Sourcepub fn id(&self) -> CapabilityId
pub fn id(&self) -> CapabilityId
Get the capability ID.
Sourcepub fn kind(&self) -> &CapabilityKind
pub fn kind(&self) -> &CapabilityKind
Get the capability kind.
Sourcepub fn scope(&self) -> &ResourceScope
pub fn scope(&self) -> &ResourceScope
Get the resource scope.
Sourcepub fn constraints(&self) -> &CapabilityConstraints
pub fn constraints(&self) -> &CapabilityConstraints
Get the constraints.
Sourcepub fn constraints_mut(&mut self) -> &mut CapabilityConstraints
pub fn constraints_mut(&mut self) -> &mut CapabilityConstraints
Get mutable constraints (for usage tracking).
Sourcepub fn grantor(&self) -> &PrincipalId
pub fn grantor(&self) -> &PrincipalId
Get the grantor.
Sourcepub fn granted_at(&self) -> i64
pub fn granted_at(&self) -> i64
Get when this was granted.
Sourcepub fn expires_at(&self) -> Option<i64>
pub fn expires_at(&self) -> Option<i64>
Get when this expires.
Sourcepub fn is_delegatable(&self) -> bool
pub fn is_delegatable(&self) -> bool
Check if this capability is delegatable.
Sourcepub fn max_delegation_depth(&self) -> u32
pub fn max_delegation_depth(&self) -> u32
Get maximum delegation depth.
Sourcepub fn delegation_depth(&self) -> u32
pub fn delegation_depth(&self) -> u32
Get the current delegation depth (0 for root capabilities).
Sourcepub fn parent_capability_id(&self) -> Option<CapabilityId>
pub fn parent_capability_id(&self) -> Option<CapabilityId>
Get the parent capability ID (for delegated capabilities).
Sourcepub fn is_revoked(&self) -> bool
pub fn is_revoked(&self) -> bool
Check if this capability has been revoked.
Sourcepub fn revoked_at(&self) -> Option<i64>
pub fn revoked_at(&self) -> Option<i64>
Get the revocation timestamp if revoked.
Sourcepub fn revocation_reason(&self) -> Option<&str>
pub fn revocation_reason(&self) -> Option<&str>
Get the revocation reason if revoked.
Sourcepub fn lifecycle_state(&self, now_ms: i64) -> CapabilityState
pub fn lifecycle_state(&self, now_ms: i64) -> CapabilityState
Get the lifecycle state at a given time per Section 5.4.
Sourcepub fn is_valid_at(&self, timestamp: i64) -> bool
pub fn is_valid_at(&self, timestamp: i64) -> bool
Check if this capability is valid at a given time.
A capability is valid if it is not revoked and not expired.
Sourcepub fn matches(
&self,
action_kind: &CapabilityKind,
resource: &ResourceId,
) -> bool
pub fn matches( &self, action_kind: &CapabilityKind, resource: &ResourceId, ) -> bool
Check if this capability matches an action.
Sourcepub fn canonical_bytes(&self) -> Vec<u8> ⓘ
pub fn canonical_bytes(&self) -> Vec<u8> ⓘ
Compute the canonical bytes for signing/verification.
Sourcepub fn delegate(
&self,
delegator_key: &SecretKey,
scope: Option<ResourceScope>,
expiry: Option<Duration>,
) -> Result<Capability>
pub fn delegate( &self, delegator_key: &SecretKey, scope: Option<ResourceScope>, expiry: Option<Duration>, ) -> Result<Capability>
Delegate this capability to another agent, creating a child capability.
Enforces:
- INV-CAP-3: child scope must be a subset of parent scope, child expiry must not exceed parent
- INV-CAP-4: delegation depth must not exceed max_delegation_depth
- Rule 5.3.3: delegated capabilities must be a subset of the delegator’s