pub struct BatchArena { /* private fields */ }Expand description
Arena allocator optimized for batch cryptographic operations.
Provides fast bump allocation for temporary data structures used during batch verification, serialization, and merkle tree building.
Implementations
Sourceimpl BatchArena
impl BatchArena
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Create a new arena with specified capacity.
Sourcepub fn for_events(count: usize) -> Self
pub fn for_events(count: usize) -> Self
Create arena sized for a batch of events.
Estimates ~1KB per event for canonical bytes + metadata.
Sourcepub fn for_hashes(count: usize) -> Self
pub fn for_hashes(count: usize) -> Self
Create arena sized for batch hash operations.
Estimates 32 bytes per hash + overhead.
Sourcepub fn alloc_bytes(&self, bytes: &[u8]) -> &[u8] ⓘ
pub fn alloc_bytes(&self, bytes: &[u8]) -> &[u8] ⓘ
Allocate a slice of bytes in the arena.
Sourcepub fn alloc_slice<T: Copy>(&self, slice: &[T]) -> &[T]
pub fn alloc_slice<T: Copy>(&self, slice: &[T]) -> &[T]
Allocate a slice in the arena.
Sourcepub fn alloc_vec_with_capacity<T>(&self, capacity: usize) -> BumpVec<'_, T>
pub fn alloc_vec_with_capacity<T>(&self, capacity: usize) -> BumpVec<'_, T>
Create a vector with capacity in the arena.
Sourcepub fn alloc_slice_fill_default<T: Default + Clone>(
&self,
count: usize,
) -> &mut [T]
pub fn alloc_slice_fill_default<T: Default + Clone>( &self, count: usize, ) -> &mut [T]
Allocate space for N items and return a slice.
Sourcepub fn alloc_hash_array(&self, count: usize) -> &mut [Hash]
pub fn alloc_hash_array(&self, count: usize) -> &mut [Hash]
Allocate a hash array in the arena.
Sourcepub fn allocated_bytes(&self) -> usize
pub fn allocated_bytes(&self) -> usize
Get the number of bytes allocated.